This crate contains kube-rs compatible bindings for Kubernetes custom resources for the cloudformation.linki.space group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
cloudformation.linki.space/v1alpha1
Stack